[rtems commit] score: Delete _Assert_Thread_dispatching_repressed

Sebastian Huber sebh at rtems.org
Wed Mar 19 07:31:15 UTC 2014


Module:    rtems
Branch:    master
Commit:    ff25926701a7c4e8cf0858bc8f41133e7d7dd45a
Changeset: http://git.rtems.org/rtems/commit/?id=ff25926701a7c4e8cf0858bc8f41133e7d7dd45a

Author:    Sebastian Huber <sebastian.huber at embedded-brains.de>
Date:      Tue Mar 18 11:49:38 2014 +0100

score: Delete _Assert_Thread_dispatching_repressed

Add _Debug_Is_thread_dispatching_allowed().  This makes it possible to
assert the opposite.

Use _ISR_Disable_without_giant()/_ISR_Enable_without_giant() to avoid
misleading secondary assertion failures.

---

 cpukit/score/Makefile.am                           |    2 +-
 cpukit/score/include/rtems/score/assert.h          |    8 +++-----
 ...pressed.c => debugisthreaddispatchingallowed.c} |   14 +++++++-------
 cpukit/score/src/smp.c                             |    2 +-
 4 files changed, 12 insertions(+), 14 deletions(-)

diff --git a/cpukit/score/Makefile.am b/cpukit/score/Makefile.am
index d747c91..7c87d1a 100644
--- a/cpukit/score/Makefile.am
+++ b/cpukit/score/Makefile.am
@@ -331,7 +331,7 @@ libscore_a_SOURCES += src/apiext.c src/chain.c src/chainappend.c \
     src/chainextract.c src/chainget.c src/chaininsert.c \
     src/chainappendempty.c src/chainprependempty.c src/chaingetempty.c \
     src/chainnodecount.c \
-    src/assertthreaddispatchingrepressed.c \
+    src/debugisthreaddispatchingallowed.c \
     src/interr.c src/isr.c src/wkspace.c src/wkstringduplicate.c
 libscore_a_SOURCES += src/profilingisrentryexit.c
 
diff --git a/cpukit/score/src/assertthreaddispatchingrepressed.c b/cpukit/score/src/debugisthreaddispatchingallowed.c
similarity index 62%
rename from cpukit/score/src/assertthreaddispatchingrepressed.c
rename to cpukit/score/src/debugisthreaddispatchingallowed.c
index 0d586f8..fa5b502 100644
--- a/cpukit/score/src/assertthreaddispatchingrepressed.c
+++ b/cpukit/score/src/debugisthreaddispatchingallowed.c
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013 embedded brains GmbH.  All rights reserved.
+ * Copyright (c) 2013-2014 embedded brains GmbH.  All rights reserved.
  *
  *  embedded brains GmbH
  *  Dornierstr. 4
@@ -21,17 +21,17 @@
 #include <rtems/score/threaddispatch.h>
 
 #if defined( RTEMS_DEBUG )
-  void _Assert_Thread_dispatching_repressed( void )
+  bool _Debug_Is_thread_dispatching_allowed( void )
   {
-    bool dispatch_is_disabled;
+    bool dispatch_allowed;
     ISR_Level level;
     Per_CPU_Control *per_cpu;
 
-    _ISR_Disable( level );
+    _ISR_Disable_without_giant( level );
     per_cpu = _Per_CPU_Get_by_index( _SMP_Get_current_processor() );
-    dispatch_is_disabled = per_cpu->thread_dispatch_disable_level != 0;
-    _ISR_Enable( level );
+    dispatch_allowed = per_cpu->thread_dispatch_disable_level == 0;
+    _ISR_Enable_without_giant( level );
 
-    _Assert( dispatch_is_disabled || _ISR_Get_level() != 0 );
+    return dispatch_allowed && _ISR_Get_level() == 0;
   }
 #endif
diff --git a/cpukit/score/src/smp.c b/cpukit/score/src/smp.c
index 389a4d6..8e57ed0 100644
--- a/cpukit/score/src/smp.c
+++ b/cpukit/score/src/smp.c
@@ -100,7 +100,7 @@ void _SMP_Broadcast_message( uint32_t message )
   uint32_t ncpus = _SMP_Get_processor_count();
   uint32_t cpu;
 
-  _Assert_Thread_dispatching_repressed();
+  _Assert( _Debug_Is_thread_dispatching_allowed() );
 
   for ( cpu = 0 ; cpu < ncpus ; ++cpu ) {
     if ( cpu != self ) {




More information about the vc mailing list
diff --git a/cpukit/score/include/rtems/score/assert.h b/cpukit/score/include/rtems/score/assert.h
index 4856eae..0248b3c 100644
--- a/cpukit/score/include/rtems/score/assert.h
+++ b/cpukit/score/include/rtems/score/assert.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013 embedded brains GmbH.  All rights reserved.
+ * Copyright (c) 2013-2014 embedded brains GmbH.  All rights reserved.
  *
  *  embedded brains GmbH
  *  Dornierstr. 4
@@ -39,15 +39,13 @@ extern "C" {
 #endif
 
 /**
  * @brief Asserts that thread dispatching is repressed.
  *
  * Thread dispatching can be repressed via _Thread_Disable_dispatch() or
  * _ISR_Disable().
  */
 #if defined( RTEMS_DEBUG )
-  void _Assert_Thread_dispatching_repressed( void );
-#else
-  #define _Assert_Thread_dispatching_repressed() ( ( void ) 0 )
+  bool _Debug_Is_thread_dispatching_allowed( void );
 #endif
 
 /**
@@ -39,15 +39,13 @@ extern "C" {
 
 /**
- * @brief Asserts that thread dispatching is repressed.
+ * @brief Returns true if thread dispatching is allowed.
  *
  * Thread dispatching can be repressed via _Thread_Disable_dispatch() or